@@ -61,20 +61,15 @@ class Subreddit:
                 flair_author = None
                 flair_post = None
 
-            nsfw = True if nsfw == "true" else False
-
-            pinned = True if pinned == "true" else False
-
-            stickied = True if stickied == "true" else False
-
-            spoiler = True if spoiler == "true" else False
-
             if not media:
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
                 if contenttext == "":
                     contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
-                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                try:
+                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                except KeyError:
+                    contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"]["media_domain_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
@@ -86,7 +81,6 @@ class Subreddit:
                 score=meme["data"]["children"][randompost]["data"]["score"],
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
-                pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
@@ -121,20 +115,17 @@ class Subreddit:
 
                 updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
-                nsfw = True if nsfw == "true" else False
-
-                pinned = True if pinned == "true" else False
-
-                stickied = True if stickied == "true" else False
-
-                spoiler = True if spoiler == "true" else False
 
                 if not media:
                     contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
                     if contenttext == "":
                         contenttext = meme["data"]["children"][randompost]["data"]["url"]
                 elif media:
-                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    try:
+                        contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    except KeyError:
+                        contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"][
+                            "media_domain_url"]
                 else:
                     contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -146,7 +137,6 @@ class Subreddit:
                     score=meme["data"]["children"][randompost]["data"]["score"],
                     downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                     nsfw=nsfw,
-                    pinned=pinned,
                     created_at=updated,
                     author=meme["data"]["children"][randompost]["data"]["author"],
                     post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
@@ -204,20 +194,16 @@ class Subreddit:
                 flair_author = None
                 flair_post = None
 
-            nsfw = True if nsfw == "true" else False
-
-            pinned = True if pinned == "true" else False
-
-            stickied = True if stickied == "true" else False
-
-            spoiler = True if spoiler == "true" else False
 
             if not media:
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
                 if contenttext == "":
                     contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
-                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                try:
+                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                except KeyError:
+                    contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"]["media_domain_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
@@ -229,7 +215,6 @@ class Subreddit:
                 score=meme["data"]["children"][randompost]["data"]["score"],
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
-                pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
@@ -264,20 +249,16 @@ class Subreddit:
 
                 updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
-                nsfw = True if nsfw == "true" else False
-
-                pinned = True if pinned == "true" else False
-
-                stickied = True if stickied == "true" else False
-
-                spoiler = True if spoiler == "true" else False
-
                 if not media:
                     contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
                     if contenttext == "":
                         contenttext = meme["data"]["children"][randompost]["data"]["url"]
                 elif media:
-                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    try:
+                        contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    except KeyError:
+                        contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"][
+                            "media_domain_url"]
                 else:
                     contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -289,7 +270,6 @@ class Subreddit:
                     score=meme["data"]["children"][randompost]["data"]["score"],
                     downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                     nsfw=nsfw,
-                    pinned=pinned,
                     created_at=updated,
                     author=meme["data"]["children"][randompost]["data"]["author"],
                     post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
@@ -346,20 +326,16 @@ class Subreddit:
                 flair_author = None
                 flair_post = None
 
-            nsfw = True if nsfw == "true" else False
-
-            pinned = True if pinned == "true" else False
-
-            stickied = True if stickied == "true" else False
-
-            spoiler = True if spoiler == "true" else False
 
             if not media:
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
                 if contenttext == "":
                     contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
-                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                try:
+                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                except KeyError:
+                    contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"]["media_domain_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
@@ -371,7 +347,6 @@ class Subreddit:
                 score=meme["data"]["children"][randompost]["data"]["score"],
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
-                pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
@@ -407,20 +382,16 @@ class Subreddit:
 
                 updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
-                nsfw = True if nsfw == "true" else False
-
-                pinned = True if pinned == "true" else False
-
-                stickied = True if stickied == "true" else False
-
-                spoiler = True if spoiler == "true" else False
-
                 if not media:
                     contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
                     if contenttext == "":
                         contenttext = meme["data"]["children"][randompost]["data"]["url"]
                 elif media:
-                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    try:
+                        contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    except KeyError:
+                        contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"][
+                            "media_domain_url"]
                 else:
                     contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -432,7 +403,6 @@ class Subreddit:
                     score=meme["data"]["children"][randompost]["data"]["score"],
                     downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                     nsfw=nsfw,
-                    pinned=pinned,
                     created_at=updated,
                     author=meme["data"]["children"][randompost]["data"]["author"],
                     post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
@@ -489,20 +459,15 @@ class Subreddit:
                 flair_author = None
                 flair_post = None
 
-            nsfw = True if nsfw == "true" else False
-
-            pinned = True if pinned == "true" else False
-
-            stickied = True if stickied == "true" else False
-
-            spoiler = True if spoiler == "true" else False
-
             if not media:
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
                 if contenttext == "":
                     contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
-                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                try:
+                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                except KeyError:
+                    contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"]["media_domain_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
@@ -514,7 +479,6 @@ class Subreddit:
                 score=meme["data"]["children"][randompost]["data"]["score"],
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
-                pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
@@ -549,20 +513,16 @@ class Subreddit:
 
                 updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
-                nsfw = True if nsfw == "true" else False
-
-                pinned = True if pinned == "true" else False
-
-                stickied = True if stickied == "true" else False
-
-                spoiler = True if spoiler == "true" else False
-
                 if not media:
                     contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
                     if contenttext == "":
                         contenttext = meme["data"]["children"][randompost]["data"]["url"]
                 elif media:
-                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    try:
+                        contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    except KeyError:
+                        contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"][
+                            "media_domain_url"]
                 else:
                     contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -574,7 +534,6 @@ class Subreddit:
                     score=meme["data"]["children"][randompost]["data"]["score"],
                     downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                     nsfw=nsfw,
-                    pinned=pinned,
                     created_at=updated,
                     author=meme["data"]["children"][randompost]["data"]["author"],
                     post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
