@@ -60,20 +60,16 @@ class User:
                 flair_author = None
                 flair_post = None
 
-            nsfw = True if nsfw == "true" else False
-
-            pinned = True if pinned == "true" else False
-
-            stickied = True if stickied == "true" else False
-
-            spoiler = True if spoiler == "true" else False
 
             if not media:
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
                 if contenttext == "":
                     contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
-                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                try:
+                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                except KeyError:
+                    contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"]["media_domain_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
@@ -85,7 +81,6 @@ class User:
                 score=meme["data"]["children"][randompost]["data"]["score"],
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
-                pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
@@ -120,20 +115,17 @@ class User:
                     flair_author = None
                     flair_post = None
 
-                nsfw = True if nsfw == "true" else False
-
-                pinned = True if pinned == "true" else False
-
-                stickied = True if stickied == "true" else False
-
-                spoiler = True if spoiler == "true" else False
 
                 if not media:
                     contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
                     if contenttext == "":
                         contenttext = meme["data"]["children"][randompost]["data"]["url"]
                 elif media:
-                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    try:
+                        contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    except KeyError:
+                        contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"][
+                            "media_domain_url"]
                 else:
                     contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -145,7 +137,6 @@ class User:
                     score=meme["data"]["children"][randompost]["data"]["score"],
                     downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                     nsfw=nsfw,
-                    pinned=pinned,
                     created_at=updated,
                     author=meme["data"]["children"][randompost]["data"]["author"],
                     post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
@@ -203,20 +194,16 @@ class User:
                 flair_author = None
                 flair_post = None
 
-            nsfw = True if nsfw == "true" else False
-
-            pinned = True if pinned == "true" else False
-
-            stickied = True if stickied == "true" else False
-
-            spoiler = True if spoiler == "true" else False
 
             if not media:
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
                 if contenttext == "":
                     contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
-                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                try:
+                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                except KeyError:
+                    contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"]["media_domain_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
@@ -228,7 +215,6 @@ class User:
                 score=meme["data"]["children"][randompost]["data"]["score"],
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
-                pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
@@ -263,20 +249,17 @@ class User:
                     flair_author = None
                     flair_post = None
 
-                nsfw = True if nsfw == "true" else False
-
-                pinned = True if pinned == "true" else False
-
-                stickied = True if stickied == "true" else False
-
-                spoiler = True if spoiler == "true" else False
 
                 if not media:
                     contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
                     if contenttext == "":
                         contenttext = meme["data"]["children"][randompost]["data"]["url"]
                 elif media:
-                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    try:
+                        contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    except KeyError:
+                        contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"][
+                            "media_domain_url"]
                 else:
                     contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -288,7 +271,6 @@ class User:
                     score=meme["data"]["children"][randompost]["data"]["score"],
                     downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                     nsfw=nsfw,
-                    pinned=pinned,
                     created_at=updated,
                     author=meme["data"]["children"][randompost]["data"]["author"],
                     post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
@@ -345,20 +327,16 @@ class User:
                 flair_author = None
                 flair_post = None
 
-            nsfw = True if nsfw == "true" else False
-
-            pinned = True if pinned == "true" else False
-
-            stickied = True if stickied == "true" else False
-
-            spoiler = True if spoiler == "true" else False
 
             if not media:
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
                 if contenttext == "":
                     contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
-                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                try:
+                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                except KeyError:
+                    contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"]["media_domain_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
@@ -370,7 +348,6 @@ class User:
                 score=meme["data"]["children"][randompost]["data"]["score"],
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
-                pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
@@ -405,20 +382,17 @@ class User:
                     flair_author = None
                     flair_post = None
 
-                nsfw = True if nsfw == "true" else False
-
-                pinned = True if pinned == "true" else False
-
-                stickied = True if stickied == "true" else False
-
-                spoiler = True if spoiler == "true" else False
 
                 if not media:
                     contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
                     if contenttext == "":
                         contenttext = meme["data"]["children"][randompost]["data"]["url"]
                 elif media:
-                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    try:
+                        contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    except KeyError:
+                        contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"][
+                            "media_domain_url"]
                 else:
                     contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -430,7 +404,6 @@ class User:
                     score=meme["data"]["children"][randompost]["data"]["score"],
                     downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                     nsfw=nsfw,
-                    pinned=pinned,
                     created_at=updated,
                     author=meme["data"]["children"][randompost]["data"]["author"],
                     post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
@@ -487,20 +460,16 @@ class User:
                 flair_author = None
                 flair_post = None
 
-            nsfw = True if nsfw == "true" else False
-
-            pinned = True if pinned == "true" else False
-
-            stickied = True if stickied == "true" else False
-
-            spoiler = True if spoiler == "true" else False
 
             if not media:
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
                 if contenttext == "":
                     contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
-                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                try:
+                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                except KeyError:
+                    contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"]["media_domain_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
@@ -512,7 +481,6 @@ class User:
                 score=meme["data"]["children"][randompost]["data"]["score"],
                 downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                 nsfw=nsfw,
-                pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
@@ -547,20 +515,17 @@ class User:
                     flair_author = None
                     flair_post = None
 
-                nsfw = True if nsfw == "true" else False
-
-                pinned = True if pinned == "true" else False
-
-                stickied = True if stickied == "true" else False
-
-                spoiler = True if spoiler == "true" else False
 
                 if not media:
                     contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
                     if contenttext == "":
                         contenttext = meme["data"]["children"][randompost]["data"]["url"]
                 elif media:
-                    contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    try:
+                        contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
+                    except KeyError:
+                        contenttext = meme["data"]["children"][randompost]["data"]["secure_media_embed"][
+                            "media_domain_url"]
                 else:
                     contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -572,7 +537,6 @@ class User:
                     score=meme["data"]["children"][randompost]["data"]["score"],
                     downvotes=meme["data"]["children"][randompost]["data"]["downs"],
                     nsfw=nsfw,
-                    pinned=pinned,
                     created_at=updated,
                     author=meme["data"]["children"][randompost]["data"]["author"],
                     post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
